pub struct StreamingSinkSubscription { /* private fields */ }Expand description
Message-bus subscriptions forwarding supported messages into a streaming sink.
Implementations
Sourceimpl StreamingSinkSubscription
impl StreamingSinkSubscription
Sourcepub fn subscribe(
sink: Rc<RefCell<StreamingDataSink>>,
clock_bridge: Option<(Rc<RefCell<dyn Clock>>, Arc<AtomicU64>)>,
) -> Self
pub fn subscribe( sink: Rc<RefCell<StreamingDataSink>>, clock_bridge: Option<(Rc<RefCell<dyn Clock>>, Arc<AtomicU64>)>, ) -> Self
Subscribes a streaming sink to typed and dynamic message-bus routes.
Sourcepub fn subscribe_named(
sink: Rc<RefCell<StreamingDataSink>>,
clock_bridge: Option<(Rc<RefCell<dyn Clock>>, Arc<AtomicU64>)>,
name: String,
) -> Self
pub fn subscribe_named( sink: Rc<RefCell<StreamingDataSink>>, clock_bridge: Option<(Rc<RefCell<dyn Clock>>, Arc<AtomicU64>)>, name: String, ) -> Self
Subscribes a sink and includes its name in write-failure diagnostics.
Sourcepub fn unsubscribe(&self)
pub fn unsubscribe(&self)
Removes all message-bus subscriptions without closing the sink.